<div style="margin-bottom: 14px; font-family: \'Roboto\', sans-serif;">
  <table>
    <tr>
      <td class="celda-i" style="width: 323px;">
        <p style="font-size: 12px; color: #002857; font-weight: 500; text-align: left; margin: 0px;">
          {{ codigo }}
        </p>
      </td>
      <td class="celda-c" style="width: 334px;">
        <p style="font-size: 12px; color: #002857; font-weight: 500; text-align: center; margin: 0px;">
          {{ fecha }}
        </p>
      </td>
      <td class="celda-d" style="width: 323px;">
        <p style="font-size: 12px; color: #002857; font-weight: 500; text-align: right; margin: 0px;">
          {{ pagina }}
        </p>
      </td>
    </tr>
  </table>
</div>
