<div style="width: 95%; margin: 15px auto; padding: 15px; background-color: #fff; border: 1px solid #ddd; border-radius: 8px; font-family: 'Roboto', sans-serif; page-break-inside: avoid;">

    {% for fila in filas %}
    <div style="display: flex; justify-content: space-between; margin-bottom: 10px;">
        <div style="width: 48%; display: flex; align-items: flex-start;">
            <span style="font-weight: bold; width: 30%; font-size: 10pt; color: #333;">{{ fila.label1 }}</span>
            <span style="width: 70%; font-size: 10pt; color: #333; word-wrap: break-word;">{{ fila.value1 }}</span>
        </div>
        <div style="width: 48%; display: flex; align-items: flex-start;">
            <span style="font-weight: bold; width: 30%; font-size: 10pt; color: #333;">{{ fila.label2 }}</span>
            <span style="width: 70%; font-size: 10pt; color: #333; word-wrap: break-word;">{{ fila.value2 }}</span>
        </div>
    </div>
    {% endfor %}
</div>