<!--Sección: situacion amenaza-->
<div style="background-color: #303d50; min-height:25px; width: 100%; margin: 0;">
    <p style="font-size: 18px; color: white; font-weight: 700; text-align: left; margin: 0 20px; padding: 10px 10px 10px 0;">
        Hechos Sobrevinientes
    </p>
</div>

<div class="subtitulo">
    <i class="fa-solid fa-align-left"></i>
    <p style="font-size: 16px; color: #002857; font-weight: 700; text-align: left; margin: 0px">
        Situación de amenaza y medio por el que se presentó
    </p>
</div>

<!-- Situación de amenaza -->
<div class="columna" style="padding-top: 0px;">
    <p style="font-size: 14px; color: #002857; font-weight: 500; text-align: left; margin: 10px 20px 10px 20px">
        25. Situación de amenaza *
    </p>
</div>

<div class="especial-dos" style="margin-bottom: 10px;">
    <table style="margin-top: 4px;">
        <tr>
            <td class="celda-i" style="width: 980px">
                <div style="position: relative; height: 35px;">
                    <!-- Amenaza -->
                    <div class="chequeo-i" style="position: absolute; left: 0; min-width: 300px; margin: 0px;">
                        <div style="position: relative;">
                            <i class="fa-regular fa-square" style="position: absolute; left: 0; font-size: 30px; color: #ccc;"></i>
                            <p style="position: absolute; left: 35px; top: 5px; font-size: 15px; color: #002857; text-align: left; margin: 0px;">
                                Amenaza (propia o de familiares)
                            </p>
                        </div>
                    </div>

                    <!-- Atentado -->
                    <div class="chequeo-i" style="position: absolute; left: 300px; min-width: 300px; margin: 0px;">
                        <div style="position: relative;">
                            <i class="fa-regular fa-square" style="position: absolute; left: 0; font-size: 30px; color: #ccc;"></i>
                            <p style="position: absolute; left: 35px; top: 5px; font-size: 15px; color: #002857; text-align: left; margin: 0px;">
                                Atentado (propio o de familiares)
                            </p>
                        </div>
                    </div>

                    <!-- Secuestro -->
                    <div class="chequeo-i" style="position: absolute; left: 600px; min-width: 300px; margin: 0px;">
                        <div style="position: relative;">
                            <i class="fa-regular fa-square" style="position: absolute; left: 0; font-size: 30px; color: #ccc;"></i>
                            <p style="position: absolute; left: 35px; top: 5px; font-size: 15px; color: #002857; text-align: left; margin: 0px;">
                                Secuestro (propio o de familiares)
                            </p>
                        </div>
                    </div>
                </div>
            </td>
        </tr>
    </table>

    <table>
        <tr>
            <td class="celda-i" style="width: 980px">
                <div style="position: relative; height: 35px;">
                    <!-- Homicidio -->
                    <div class="chequeo-i" style="position: absolute; left: 0; min-width: 300px;">
                        <div style="position: relative;">
                            <i class="fa-regular fa-square" style="position: absolute; left: 0; font-size: 30px; color: #ccc;"></i>
                            <p style="position: absolute; left: 35px; top: 5px; font-size: 15px; color: #002857; text-align: left; margin: 0px;">
                                Homicidio de familiar(es)
                            </p>
                        </div>
                    </div>

                    <!-- Extorsión -->
                    <div class="chequeo-i" style="position: absolute; left: 300px; min-width: 300px;">
                        <div style="position: relative;">
                            <i class="fa-regular fa-square" style="position: absolute; left: 0; font-size: 30px; color: #ccc;"></i>
                            <p style="position: absolute; left: 35px; top: 5px; font-size: 15px; color: #002857; text-align: left; margin: 0px;">
                                Extorsión
                            </p>
                        </div>
                    </div>

                    <!-- Reclutamiento ilegal -->
                    <div class="chequeo-i" style="position: absolute; left: 600px; min-width: 300px;">
                        <div style="position: relative;">
                            <i class="fa-regular fa-square" style="position: absolute; left: 0; font-size: 30px; color: #ccc;"></i>
                            <p style="position: absolute; left: 35px; top: 5px; font-size: 15px; color: #002857; text-align: left; margin: 0px;">
                                Reclutamiento ilegal
                            </p>
                        </div>
                    </div>
                </div>
            </td>
        </tr>
    </table>

    <table>
        <tr>
            <td class="celda-i" style="width: 156px">
                <div style="position: relative; height: 35px;">
                    <!-- Otra -->
                    <div class="chequeo-i" style="position: absolute; left: 0; min-width: 300px;">
                        <div style="position: relative;">
                            <i class="fa-regular fa-square" style="position: absolute; left: 0; font-size: 30px; color: #ccc;"></i>
                            <p style="position: absolute; left: 35px; top: 5px; font-size: 15px; color: #002857; text-align: left; margin: 0px;">
                                Otra
                            </p>
                        </div>
                    </div>
                </div>
            </td>
        </tr>
    </table>
</div>

<!-- Medio por el que se presentó -->
<div class="columna" style="padding-top: 0px;">
    <p style="font-size: 14px; color: #002857; font-weight: 500; text-align: left; margin: 10px 20px 10px 20px">
        26. Medio por el que se presentó *
    </p>
</div>

<div class="especial-dos" style="margin-bottom: 10px;">
    <table style="margin-top: 4px;">
        <tr>
            <td class="celda-i" style="width: 980px">
                <div style="position: relative; height: 35px;">
                    <!-- Telefónica -->
                    <div class="chequeo-i" style="position: absolute; left: 0; min-width: 300px;">
                        <div style="position: relative;">
                            <i class="fa-regular fa-square" style="position: absolute; left: 0; font-size: 30px; color: #ccc;"></i>
                            <p style="position: absolute; left: 35px; top: 5px; font-size: 15px; color: #002857; text-align: left; margin: 0px;">
                                Telefónica
                            </p>
                        </div>
                    </div>

                    <!-- Verbal -->
                    <div class="chequeo-i" style="position: absolute; left: 300px; min-width: 300px;">
                        <div style="position: relative;">
                            <i class="fa-regular fa-square" style="position: absolute; left: 0; font-size: 30px; color: #ccc;"></i>
                            <p style="position: absolute; left: 35px; top: 5px; font-size: 15px; color: #002857; text-align: left; margin: 0px;">
                                Verbal
                            </p>
                        </div>
                    </div>

                    <!-- Escrita -->
                    <div class="chequeo-i" style="position: absolute; left: 600px; min-width: 300px;">
                        <div style="position: relative;">
                            <i class="fa-regular fa-square" style="position: absolute; left: 0; font-size: 30px; color: #ccc;"></i>
                            <p style="position: absolute; left: 35px; top: 5px; font-size: 15px; color: #002857; text-align: left; margin: 0px;">
                                Escrita
                            </p>
                        </div>
                    </div>
                </div>
            </td>
        </tr>
    </table>

    <table style="margin-top: 4px;">
        <tr>
            <td class="celda-i" style="width: 980px">
                <div style="position: relative; height: 35px;">
                    <!-- A través de terceros -->
                    <div class="chequeo-i" style="position: absolute; left: 0; min-width: 300px;">
                        <div style="position: relative;">
                            <i class="fa-regular fa-square" style="position: absolute; left: 0; font-size: 30px; color: #ccc;"></i>
                            <p style="position: absolute; left: 35px; top: 5px; font-size: 15px; color: #002857; text-align: left; margin: 0px;">
                                A través de terceros
                            </p>
                        </div>
                    </div>

                    <!-- Simbólica -->
                    <div class="chequeo-i" style="position: absolute; left: 300px; min-width: 300px;">
                        <div style="position: relative;">
                            <i class="fa-regular fa-square" style="position: absolute; left: 0; font-size: 30px; color: #ccc;"></i>
                            <p style="position: absolute; left: 35px; top: 5px; font-size: 15px; color: #002857; text-align: left; margin: 0px;">
                                Simbólica
                            </p>
                        </div>
                    </div>

                    <!-- Redes sociales -->
                    <div class="chequeo-i" style="position: absolute; left: 600px; min-width: 300px;">
                        <div style="position: relative;">
                            <i class="fa-regular fa-square" style="position: absolute; left: 0; font-size: 30px; color: #ccc;"></i>
                            <p style="position: absolute; left: 35px; top: 5px; font-size: 15px; color: #002857; text-align: left; margin: 0px;">
                                Redes sociales
                            </p>
                        </div>
                    </div>
                </div>
            </td>
        </tr>
    </table>
</div>

<!-- Fecha y lugar del suceso -->
{% include "sistema/subtitulo_icono.html" with icono="fa-solid fa-calendar" titulo="Fecha y lugar del suceso" %}

{% include "sistema/fila_cuatro_zona.html" with label1="27. Fecha *" ancho1="20%" valor1="" label2="28. Departamento *" ancho2="20%" valor2="" label3="29. Municipio *" ancho3="20%" valor3="" label4="30. Zona *" ancho4="25%" valor4="" %}

<!-- Relato del hecho -->
{% include "sistema/texarea.html" with label="31. Relato Hechos" alto="594px" valor="" %}