<div class="subtitulo" style="display: flex; align-items: flex-start; ">
  <i class="{{ icono }}" style="font-size: 18px; margin-right: 10px; flex-shrink: 0;"></i>
  <span style="font-size: 16px; color: #002857; font-weight: 700; flex: 1; line-height: 1.4;">
    {{ titulo }}
  </span>
</div>