<table>
    <tr>
        <td class="celda-i" style="width: {{ ancho1 }};">
            <label>{{ label1 }}</label>
            <input type="text" value="{{ valor1 }}">
        </td>
        <td class="celda-c" style="width: {{ ancho2 }};">
            <label>{{ label2 }}</label>
            <input type="text" value="{{ valor2 }}">
        </td>
        <td class="celda-c" style="width: {{ ancho3 }};">
            <label>{{ label3 }}</label>
            <input type="text" value="{{ valor3 }}">
        </td>
        <td class="celda-d" style="width: {{ ancho4 }};">
            <label>{{ label4 }}</label>
            <p>{{ valor4 }}</p>
        </td>
    </tr>
</table>
