<table style="width: 95%; margin: 15px auto; border-collapse: collapse; font-family: 'Roboto', sans-serif; page-break-inside: avoid; line-height: 1.6;">
  
  <!-- Fila 1 -->
  <tr>
    <td style="padding: 5px 0; font-size: 16px; color: #002857; width: {{ancho1}}">
      <strong>Nombre de la persona evaluada:</strong> {{ nombre_evaluado }}
    </td>
    <td style="padding: 5px 0; font-size: 16px; color: #002857; width: {{ancho2}};">
      <strong>Fecha solicitud UNP:</strong> {{ fecha_solicitud_unp }}
    </td>
  </tr>

  <!-- Fila 2 -->
  <tr>
    <td style="padding: 5px 0; font-size: 16px; color: #002857; width: {{ancho3}}">
      <strong>Identificación:</strong> {{ identificacion }}
    </td>
    <td style="padding: 5px 0; font-size: 16px; color: #002857; width: {{ancho4}};">
      <strong>Fecha recibo Subdirección ER:</strong> {{ fecha_recibo_subd }}
    </td>
  </tr>

  <!-- Fila 3 -->
  <tr>
    <td style="padding: 5px 0; font-size: 16px; color: #002857; width: {{ancho5}}">
      <strong>Género:</strong> {{ genero }}
    </td>
    <td style="padding: 5px 0; font-size: 16px; color: #002857; width: {{ancho6}};">
      <strong>Fecha expedición Orden:</strong> {{ fecha_expedicion_orden }}
    </td>
  </tr>

</table>