<div style="padding: 10px 16px;">
  <div style="font-size:13px; font-weight:700; color:#1e293b;">{{ label|default:"Anexos" }}</div>
  <div style="border:1px dashed #cbd5e1; border-radius:4px; padding:14px; color:#64748b;">Lista de anexos y documentos adjuntos (espacio libre).</div>
</div>