<div class="especial" style="width: 96%; margin-top: 10px; padding-bottom: 5px;">
    <table>
        <tr>
            <td class="celda-i" style="width: 30px; padding: 0; vertical-align: top;">
                <label style="padding-top: 8px; margin: 0; font-weight: bold;" for="anexo1">1.</label>
            </td>
            <td class="celda-c" style="width: 100%; padding-left: 10px;">
                <input style="min-height: 25px; width: 100%; background: white; border: none; border-bottom: 1px solid #002857; border-radius: 0; padding: 5px 0;" type="text" id="anexo1" name="anexo1" value="" readonly>
            </td>
        </tr>
        <tr>
            <td class="celda-i" style="width: 30px; padding: 0; vertical-align: top;">
                <label style="padding-top: 8px; margin: 0; font-weight: bold;" for="anexo2">2.</label>
            </td>
            <td class="celda-c" style="width: 100%; padding-left: 10px;">
                <input style="min-height: 25px; width: 100%; background: white; border: none; border-bottom: 1px solid #002857; border-radius: 0; padding: 5px 0;" type="text" id="anexo2" name="anexo2" value="" readonly>
            </td>
        </tr>
        <tr>
            <td class="celda-i" style="width: 30px; padding: 0; vertical-align: top;">
                <label style="padding-top: 8px; margin: 0; font-weight: bold;" for="anexo3">3.</label>
            </td>
            <td class="celda-c" style="width: 100%; padding-left: 10px;">
                <input style="min-height: 25px; width: 100%; background: white; border: none; border-bottom: 1px solid #002857; border-radius: 0; padding: 5px 0;" type="text" id="anexo3" name="anexo3" value="" readonly>
            </td>
        </tr>
        <tr>
            <td class="celda-i" style="width: 30px; padding: 0; vertical-align: top;">
                <label style="padding-top: 8px; margin: 0; font-weight: bold;" for="anexo4">4.</label>
            </td>
            <td class="celda-c" style="width: 100%; padding-left: 10px;">
                <input style="min-height: 25px; width: 100%; background: white; border: none; border-bottom: 1px solid #002857; border-radius: 0; padding: 5px 0;" type="text" id="anexo4" name="anexo4" value="" readonly>
            </td>
        </tr>
        <tr>
            <td class="celda-i" style="width: 30px; padding: 0; vertical-align: top;">
                <label style="padding-top: 8px; margin: 0; font-weight: bold;" for="anexo5">5.</label>
            </td>
            <td class="celda-c" style="width: 100%; padding-left: 10px;">
                <input style="min-height: 25px; width: 100%; background: white; border: none; border-bottom: 1px solid #002857; border-radius: 0; padding: 5px 0;" type="text" id="anexo5" name="anexo5" value="" readonly>
            </td>
        </tr>
        <tr>
            <td class="celda-i" style="width: 30px; padding: 0; vertical-align: top;">
                <label style="padding-top: 8px; margin: 0; font-weight: bold;" for="anexo6">6.</label>
            </td>
            <td class="celda-c" style="width: 100%; padding-left: 10px;">
                <input style="min-height: 25px; width: 100%; background: white; border: none; border-bottom: 1px solid #002857; border-radius: 0; padding: 5px 0;" type="text" id="anexo6" name="anexo6" value="" readonly>
            </td>
        </tr>
    </table>
</div>