<table>
    <tr>
        <td class="celda-i" style="width: 530px">
            <label>{{ labelSelect }}</label>
            <div style="position: relative; height: 35px;">
                <!-- Opción 1: Femenino -->
                <div class="chequeo-i" style="position: absolute; left: 0; min-width: 200px;">
                    <div style="position: relative;">
                        <i class="fa-regular fa-square" style="position: absolute; left: 0; font-size: 30px; color: #ccc;"></i>
                        {% if genero == 1 %}
                            <i class="fa-regular fa-square-check" style="position: absolute; left: 0; font-size: 30px; color: #888;"></i>
                        {% endif %}
                        <p style="position: absolute; left: 35px; top: 5px; font-size: 15px; color: #002857; text-align: left; margin: 0px;">
                            {{ labelSelected1 }}
                        </p>
                    </div>
                </div>

                <!-- Opción 2: Masculino -->
                <div class="chequeo-i" style="position: absolute; left: 185px; min-width: 200px;">
                    <div style="position: relative;">
                        <i class="fa-regular fa-square" style="position: absolute; left: 0; font-size: 30px; color: #ccc;"></i>
                        {% if genero == 2 %}
                        <i class="fa-regular fa-square-check" style="position: absolute; left: 0; font-size: 30px; color: #888;"></i>
                        {% endif %}
                        <p style="position: absolute; left: 35px; top: 5px; font-size: 15px; color: #002857; text-align: left; margin: 0px;">
                            {{ labelSelected2 }}
                        </p>
                    </div>
                </div>

                <!-- Opción 3: No binario -->
                <div class="chequeo-i" style="position: absolute; left: 365px; min-width: 200px;">
                    <div style="position: relative;">
                        <i class="fa-regular fa-square" style="position: absolute; left: 0; font-size: 30px; color: #ccc;"></i>
                        {% if genero == 3 %}
                        <i class="fa-regular fa-square-check" style="position: absolute; left: 0; font-size: 30px; color: #888;"></i>
                        {% endif %}
                        <p style="position: absolute; left: 35px; top: 5px; font-size: 15px; color: #002857; text-align: left; margin: 0px;">
                            {{ labelSelected3 }}
                        </p>
                    </div>
                </div>
            </div>
        </td>
    </tr>
</table>