<div class="encabezado" style="margin: 5px 20px 5px 20px; min-height: 83px">
    <img src="data:image/png;base64,{{ logo_unp }}" alt="Logo UNP" class="img-izquierda">
    <img src="data:image/jpeg;base64,{{ logo_min }}" alt="Logo MinInterior" class="img-derecha">
</div>
