<table style="width: 100%; margin-top: 15px;">
    <tr>
        <!-- Firma izquierda -->
        <td style="width: 50%; padding-left: 20px; text-align: left; vertical-align: top;">
            <label style="font-weight: bold; color: #002857; display: block; margin-bottom: 4px;">
                {{label1}}
            </label>
            <input type="text" style="height: {{ alto1 }}; width: {{ancho1}};">
            <label style="color: #002857;">
                <strong>{{ nombrei }}</strong>
                
            </label>
            <label style="color: #002857;">
                <strong>{{ documentoi }}</strong>
            </label>

        </td>

        <!-- Firma derecha -->
        <td style="width: 50%; padding-left: 20px; text-align: left; vertical-align: top;">
            <label style="font-weight: bold; color: #002857; display: block; margin-bottom: 4px;">
                {{label2}}
            </label>
            <input type="text" style="height: {{ alto2 }}; width: {{ancho2}};">
            <label style="color: #002857;">
                <strong>{{ nombred }}</strong><br>
                <strong>{{ documentod }}</strong><br>
                <strong>{{ tarjetad }}</strong><br>
            </label>
        </td>
    </tr>
</table>