<div style="position: relative; height: 35px;">
  <table style="position: absolute; right: 0; width: 100%;">
    <tr>
      <td class="celda-i" style="width: {{ ancho1 }};">
        <span style="font-size: 15px; color: #002857;">
          <b>{{ titulo }}</b>
        </span>
      </td>
      <td class="celda-c" style="width: {{ ancho2 }};">
        <input type="text" value="{{ mision }}"
          style="min-height: 30px; width: 100%; font-size: 15px; padding: 4px 8px; border: 1px solid #b0b0b0; border-radius: 4px;">
      </td>
      <td class="celda-c" style="width: {{ ancho3 }};">
        <span style="font-size: 15px; color: #002857;">
          <b>{{ titulo2 }}</b>
        </span>
      </td>
      <td class="celda-d" style="width: {{ ancho4 }};">
        <input type="text"  value="{{ mision2 }}"
          style="min-height: 30px; width: 100%; font-size: 15px; padding: 4px 8px; border: 1px solid #b0b0b0; border-radius: 4px;">
      </td>
    </tr>
  </table>
</div>
