<!-- templates/components/tabla_instructivo.html -->
<div class="instructivo" style="margin-top: 5px;">
    <table>
        <tr>
            <th style="background-color: #303d50; color: white; font-size: 18px; height: 50px; border-right: 2px solid #ffffff;">Campo</th>
            <th style="background-color: #303d50; color: white; font-size: 18px;height: 50px">Información que debe contener</th>
        </tr>
        {% for fila in filas %}
            {% include "sistema/fila_instructivo.html" with fila=fila %}
        {% endfor %}
    </table>
</div>