<table>
  <tr>
      <td class="celda-i" style="width: {{ ancho1 }};">
          <label>{{ label1 }}</label>
          <input type="text" value="{{ valor1 }}">
      </td>
      <td class="celda-c" style="width: {{ ancho2 }};">
          <label>{{ label2 }}</label>
          <input type="text" value="{{ valor2 }}">
      </td>
      <td class="celda-c" style="width: {{ ancho3 }};">
          <label>{{ label3 }}</label>
          <input type="text" value="{{ valor3 }}">
      </td>
      <td class="celda-d" style="width: {{ ancho4 }};">
          <label>{{ label4 }}</label>
          <div style="position: relative; height: 35px;">
              <div class="chequeo-i" style="position: absolute; left: 0; min-width: 200px;">
                  <div style="position: relative;">
                      {% if valor4 == "True" %}
                        <i class="fa-regular fa-square-check" style="position: absolute; left: 0; font-size: 30px; color: #888;"></i>
                      {% else %}
                          <i class="fa-regular fa-square" style="position: absolute; left: 0; font-size: 30px; color: #ccc;"></i>
                      {% endif %}
                      <p style="position: absolute; left: 35px; top: 5px; font-size: 15px; color: #002857; text-align: left; margin: 0px;">
                        Si
                      </p>
                  </div>
              </div>

              <div class="chequeo-i" style="position: absolute; left: 100px; min-width: 200px;">
                  <div style="position: relative;">
                      {% if valor4 == "False" %}
                          <i class="fa-regular fa-square-check" style="position: absolute; left: 0; font-size: 30px; color: #888;"></i>
                      {% else %}
                          <i class="fa-regular fa-square" style="position: absolute; left: 0; font-size: 30px; color: #ccc;"></i>
                      {% endif %}
                      <p style="position: absolute; left: 35px; top: 5px; font-size: 15px; color: #002857; text-align: left; margin: 0px;">
                        No
                      </p>
                  </div>
              </div>
          </div>
      </td>
  </tr>
</table>