<div style="display:flex; justify-content:space-between; align-items:center; padding: 8px 16px; border-top:1px solid #e5e7eb; margin-top: 8px; font-size: 12px; color:#475569;">
  <div>
    <span style="font-weight:700; color:#0f172a;">{{ codigo|default:"DOC-FT-01" }}</span>
    <span style="margin-left:10px;">{{ fecha|default:"Oficialización: --/--/----" }}</span>
  </div>
  <div style="font-weight:700; color:#0f172a;">{{ pagina|default:"Pág. 1 de 1" }}</div>
  <div style="page-break-after: always;"></div>