<div style="border: 1px solid #303d50; border-radius: 5px; font-family: 'Roboto', sans-serif; margin-top: 10px;">
  <table>
    <tr>
        <td class="celda-i" style="width: 200px">
            <div style="position: relative; height: 30px; margin-top: 0px; ">
                <div style="position: relative;">
                    <p style="position: absolute; left: 0px; top: 5px; font-size: 15px; color: #002857; text-align: left; margin: 0px;">
                        Archívese en:
                    </p>
                </div>
            </div>
        </td>
        <td class="celda-c" style="position: relative; width: 900px;">
            <input style="margin: 3px;" type="text" id="veredaDomicilio" name="" value="">
        </td>
    </tr>
  </table>
</div>