<!-- templates/components/firmas_elaboracion.html -->
<div class="ofi" style="margin-top: 0px;">
    <table>
        <!-- Encabezado "FIRMAS DE ELABORACIÓN, REVISIÓN Y APROBACIÓN DEL DOCUMENTO" -->
        <tr>
            <th class="v-inicial" style="text-align: left; border-right: none; border-left: none; border-top: none; padding: 10px 0 10px 10px;" colspan="2">
                <p style="font-size: 6px; padding: 0px 2px; text-align: center; margin: 0;">FIRMAS DE ELABORACIÓN, REVISIÓN Y APROBACIÓN DEL DOCUMENTO</p>
            </th>
        </tr>

        <!-- Fila "Elaboró" -->
        <tr>
            <td class="v-descripcion" style="text-align: left; border-top: none; border-left: none; padding: 10px 0 10px 10px;">
                <p>
                    <b>Elaboró</b><br>
                    <b>Nombre:</b> {{ firmas.elaboro.nombre }}<br>
                    <b>Cargo:</b> {{ firmas.elaboro.cargo }}
                </p>
            </td>
            <td class="v-inicial" style="text-align: left; border-top: none; border-right: none; border-left: none; padding: 10px 0 10px 10px;"></td>
        </tr>

        <!-- Fila "Revisó" -->
        <tr>
            <td class="v-descripcion" style="text-align: left; border-top: none; border-left: none; padding: 10px 0 10px 10px;">
                <p>
                    <b>Revisó</b><br>
                    <b>Nombre:</b> {{ firmas.reviso.nombre }}<br>
                    <b>Cargo:</b> {{ firmas.reviso.cargo }}
                </p>
            </td>
            <td class="v-inicial" style="text-align: left; border-top: none; border-right: none; border-left: none; padding: 10px 0 10px 10px;"></td>
        </tr>

        <!-- Fila "Aprobó" -->
        <tr>
            <td class="v-descripcion" style="text-align: left; border-top: none; border-left: none; padding: 10px 0 10px 10px;">
                <p>
                    <b>Aprobó</b><br>
                    <b>Nombre:</b> {{ firmas.aprobo.nombre }}<br>
                    <b>Cargo:</b> {{ firmas.aprobo.cargo }}
                </p>
            </td>
            <td class="v-inicial" style="text-align: left; border-top: none; border-right: none; border-left: none; padding: 10px 0 10px 10px;"></td>
        </tr>

        <!-- Encabezado "FIRMA DE OFICIALIZACIÓN DEL DOCUMENTO" -->
        <tr style="text-align: center;">
            <th class="v-inicial" style="min-width: 500px; text-align: left; border-right: none; border-left: none; border-top: none; padding: 10px 0 10px 10px;" colspan="2">
                <p style="text-align: center; font-size: 6px; padding: 0px 2px; margin: 0;">FIRMA DE OFICIALIZACIÓN DEL DOCUMENTO - SISTEMA INTEGRADO DE GESTIÓN MIPG-SIG</p>
            </th>
        </tr>

        <!-- Fila "Oficializó" -->
        <tr>
            <td class="v-descripcion" style="text-align: left; border-bottom: 1px solid #303d50; border-left: none; padding: 10px 0 10px 10px;">
                <p>
                    <b>Oficializó</b><br>
                    <b>Nombre:</b> {{ firmas.oficializo.nombre }}<br>
                    <b>Cargo:</b> {{ firmas.oficializo.cargo }}
                </p>
            </td>
            <td class="v-inicial" style="text-align: left; border-bottom: 1px solid #303d50; border-right: none; border-left: none; padding: 10px 0 10px 10px;"></td>
        </tr>
    </table>
</div>