<!-- templates/components/control_cambios_dinamico.html -->
<div style="background-color: #303d50; width: 100%; margin: 0px;">
    <p style="font-size: 18px; color: white; font-weight: 700; text-align: left; margin: 0px 20px; padding: 10px 0;">
        Control de Cambios
    </p>
</div>
<div class="version">
    <table>
        <!-- Encabezado fijo -->
        <tr>
            <th class="v-inicial" style="text-align: left; border-left: none; border-top: none; padding: 10px 0 10px 10px; min-width: 120px;">
                Versión inicial
            </th>
            <th class="v-descripcion" style="text-align: center; border-top: none; padding: 10px 0 10px 10px;">
                Descripción de la creación o cambio del documento
            </th>
            <th class="v-inicial" style="text-align: center; border-left: none; border-top: none; padding: 10px 0 10px 10px; min-width: 110px;">
                Fecha
            </th>
            <th class="v-inicial" style="text-align: center; border-right: none; border-top: none; padding: 10px 0 10px 10px; min-width: 120px;">
                Versión final
            </th>
        </tr>

        <!-- Filas dinámicas -->
        {% for fila in filas %}
        <tr{% if fila.height %} style="height: {{ fila.height }};"{% endif %}>
            <td class="v-inicial" style="text-align: center; border-left: none; min-width: 120px; {% if not forloop.last %}border-bottom: none;{% endif %}">
                {{ fila.version_inicial }}
            </td>
            <td class="v-descripcion" style="text-align: left; {% if not forloop.last %}border-bottom: none;{% endif %}">
                <p>{{ fila.descripcion|linebreaksbr }}</p>
            </td>
            <td class="v-inicial" style="text-align: center; min-width: 110px; {% if not forloop.last %}border-bottom: none;{% endif %}">
                {{ fila.fecha }}
            </td>
            <td class="v-inicial" style="text-align: center; border-right: none; min-width: 120px; {% if not forloop.last %}border-bottom: none;{% endif %}">
                {{ fila.version_final }}
            </td>
        </tr>
        {% endfor %}
    </table>
</div>